<?php

namespace app\admin\controller;

use app\admin\logic\VideoGroupLogic;
use app\BaseController;
use app\model\CommonModel;
use think\exception\ValidateException;
use think\facade\Config;
use think\facade\Validate;

//【视频分组】
class VideoGroup extends BaseController
{
    //获取视频分组列表
    public function list()
    {
        $param = $this->request->only(['page' => 1, 'size' => 10, 'status' => '', 'company_title' => '', 'card_title' => ''], 'post');

        return VideoGroupLogic::list($param);
    }

    //添加视频分组
    public function add()
    {
        $param = $this->request->only(['company_id', 'card_id', 'remark' => ''], 'post');

        $val = Validate::rule(Config::get('validate_rules.VideoGroupAdd'));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return VideoGroupLogic::add($param);
    }

    //获取视频分组详情
    public function read()
    {
        $id = $this->request->post('id/d', 0);
        return VideoGroupLogic::read($id);
    }

    //编辑视频分组
    public function edit()
    {
        $param = $this->request->only(['id', 'company_id', 'card_id','remark' => ''], 'post');

        $val = Validate::rule(array_merge(Config::get('validate_rules.VideoGroupAdd'), ['id|视频分组id' => 'require|number|gt:0']));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return VideoGroupLogic::edit($param);
    }

    //视频分组启禁用
    public function status()
    {
        $param = $this->request->only(['id','status'],'post');

        $val = Validate::rule(Config::get('validate_rules.status'));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return VideoGroupLogic::status($param);
    }

    //删除视频分组
    public function delete()
    {
        $ids = $this->request->post('id/a', []);
        return VideoGroupLogic::delete($ids);
    }

    //视频分组置顶
    public function top()
    {
        $param = $this->request->only(['id','is_top'],'post');

        $val = Validate::rule([
            'id' => 'require|number|gt:0',
            'is_top|是否置顶' => 'require|number|in:' . CommonModel::$top_no . ',' . CommonModel::$top_yes,
        ]);

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return VideoGroupLogic::top($param);
    }

}