<?php

namespace app\admin\controller;

use app\admin\logic\VideoGroupItemLogic;
use app\BaseController;
use app\model\CommonModel;
use think\exception\ValidateException;
use think\facade\Config;
use think\facade\Validate;

//【视频分组明细】
class VideoGroupItem extends BaseController
{
    //获取视频分组明细列表
    public function list()
    {
        $param = $this->request->only(['video_group_id' => 0, 'page' => 1, 'size' => 10, 'video_title' => ''], 'post');

        return VideoGroupItemLogic::list($param);
    }

    //添加视频分组明细
    public function add()
    {
        $param = $this->request->only(['video_group_id', 'video_id'], 'post');

        $val = Validate::rule(Config::get('validate_rules.VideoGroupItemAdd'));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return VideoGroupItemLogic::add($param);
    }

    //获取视频分组明细详情
    public function read()
    {
        $id = $this->request->post('id/d', 0);
        return VideoGroupItemLogic::read($id);
    }

    //编辑视频分组明细
    public function edit()
    {
        $param = $this->request->only(['id', 'video_id'], 'post');

        $val = Validate::rule([
            'id|视频分组明细id' => 'require|number|gt:0',
            'video_id|视频id' => 'require|number|gt:0',
        ]);

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return VideoGroupItemLogic::edit($param);
    }

    //删除视频分组明细
    public function delete()
    {
        $ids = $this->request->post('id/a', []);
        return VideoGroupItemLogic::delete($ids);
    }

    //视频分组明细置顶
    public function top()
    {
        $param = $this->request->only(['id', 'is_top'], 'post');

        $val = Validate::rule([
            'id' => 'require|number|gt:0',
            'is_top|是否置顶' => 'require|number|in:' . CommonModel::$top_no . ',' . CommonModel::$top_yes,
        ]);

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return VideoGroupItemLogic::top($param);
    }

}